# Pascal VOC Tools

This package includes some tools about pascal voc format dataset like read xml, write xml, resize image.

version 0.0.1:
xml_writer: fork from https://github.com/AndrewCarterUK/pascal-voc-writer
